@@ -2,8 +2,8 @@
 # # Script     : Tkx::TclTk::Bind::ImageLibrary.pm                             #
 # # -------------------------------------------------------------------------- #
 # # Copyright  : Frei unter GNU General Public License  bzw.  Artistic License #
-# # Authors    : JVBSOFT - Jrgen von Brietzke                   0.001 - 1.300 #
-# # Version    : 1.300                                             21.Dez.2015 #
+# # Authors    : JVBSOFT - Jrgen von Brietzke                   0.001 - 1.400 #
+# # Version    : 1.400                                             14.Feb.2016 #
 # # -------------------------------------------------------------------------- #
 # # Function   : Bindet die TclTk 'Img1.4.0.4' Bibliothek an Perl::Tkx         #
 # # -------------------------------------------------------------------------- #
@@ -12,15 +12,15 @@
 # # Standards  : Perl-Best-Practices                       severity 1 (brutal) #
 # # -------------------------------------------------------------------------- #
 # # Module     : Enc::C                                 ActivePerl-REPO-Module #
-# #              Perl::Modern::Perl                                            #
+# #              Modern::PBP::Perl                                             #
 # #              Tkx::TclTk::Bind                                              #
 # ##############################################################################
 
-package Tkx::TclTk::Bind::ImageLibrary 1.300;
+package Tkx::TclTk::Bind::ImageLibrary 1.400;
 
 # ##############################################################################
 
-use Perl::Modern::Perl qw{5.12};
+use Modern::PBP::Perl qw{5.12};
 use Tkx::TclTk::Bind qw{ &load_library };
 
 # ##############################################################################
@@ -66,7 +66,7 @@ Tkx::TclTk::Bind::ImageLibrary - Adds additional graphic formats to Tkx.
 
 =head1 VERSION
 
-This document describes Perl::Modern::Perl version 1.300.
+This document describes Perl::Modern::Perl version 1.400.
 
 
 =head1 SYNOPSIS
@@ -135,7 +135,7 @@ The following pragmas and modules are required:
 
 =head2  CPAN or ActiveState Repository
 
-   - Perl::Modern::Perl
+   - Modern::PBP::Perl
    - Tkx::TclTk::Bind
 
 
